"use strict";
(self["webpackChunkpyams_app_msc"] = self["webpackChunkpyams_app_msc"] || []).push([["src_pyams_app_msc_skin_resources_src_js_i18n_fr_js"],{

/***/ "./src/pyams_app_msc/skin/resources/src/js/i18n/fr.js":
/*!************************************************************!*\
  !*** ./src/pyams_app_msc/skin/resources/src/js/i18n/fr.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var fr = {
  BTN_CLOSE: "Fermer",
  SUCCESS: "Opération effectuée",
  ERROR_OCCURRED: "Une erreur s'est produite !",
  ERRORS_OCCURRED: "Des erreurs se sont produites !"
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (fr);

/***/ })

}]);
//# sourceMappingURL=src_pyams_app_msc_skin_resources_src_js_i18n_fr_js.js.map