
@import "variables";


.search-results {
	.header {
		font-size: 95%;
		line-height: 1.2;
	}
	.tags {
		z-index: 2;
	}
}


@media only screen and (min-width: $media-lg) and (max-width: $media-xl) {
	.col-lg-1,
	.col-lg-2,
	.col-lg-3,
	.col-lg-4 {
		.search-results {

			>div {
				flex-direction: column;
			}

			.thumbnail {
				margin-right: 0 !important;
				margin-bottom: 0.75em;

				img {
					width: 100%;
					max-width: 100%;
				}
			}
		}
	}
}
