
@import "variables";


/**
 * Calendar styles
 */

.fc-daygrid {
  .fc-col-header-cell {
    background-color: $primary-dark-1;
    color: $page-bg;
  }
  .fc-day {
    .fc-event {
      cursor: pointer;
    }
  }
}
