

@import "_variables.scss";


.alert {
  *:last-child {
    margin-bottom: 0;
  }
}

.form-group {
  label {
    &.empty {
      display: none;
    }
  }
  &.required-field {
    >label {
      &::after {
        content: ' * ';
        color: $danger;
        font-weight: $form-required-font-weight;
      }
    }
    .control-label {
      &::after {
        content: '*';
        display: inline-block;
        color: $danger;
      }
    }
  }
  .object-field {
    .form-group {
      .required-field {
        position: relative;

        &::after {
          position: absolute;
          right: 0;
          content: ' * ';
          color: $danger;
          font-weight: $form-required-font-weight;
        }
      }
    }
  }

  .input {
    .error {
      color: $danger;
    }
  }
}

.datepicker {
  table {
    thead {
      th,
      td {
        background-color: $page-bg;
        color: $body-bg;
      }
    }
  }
}

footer {
  button {
    margin: 0 0.25em;
  }
}