

@import "variables";


#footer {

  color: $footer;

  .border-bottom {
    border-color: $footer-border-bottom !important;
  }

  hr {
    border-color: $footer-hr-border !important;
  }

  a {
    color: $footer-link;
    font-style: normal;
    font-weight: $link-font-weight;
  }

  .contact-details {
    margin: 0;
    padding: 10px 0 0 0;
    list-style-type: none;

    li {
      margin: 0 0 15px 45px;

      &::before {
        display: block;
        position: absolute;
        content: '';
        left: -45px;
        top: -8px;
        width: 36px;
        height: 36px;
        border-radius: 99%;
        background-color: $footer-icon-bg;
        background-repeat: no-repeat;
        background-position: center;
      }
      &.contact-phone::before {
        background-image: url(../img/phone.png);
      }
      &.contact-mail::before {
        background-image: url(../img/email.png);
      }
      &.contact-address::before {
        background-image: url(../img/map.png);
      }
      &.contact-hours::before {
        background-image: url(../img/clock.png);
      }
      &.contact-form::before {
        background-image: url(../img/form.png);
      }
      &.contact-social::before {
        background-color: $page-bg;
        background-image: url(../img/social-icons.png);
      }
      &.contact-facebook::before {
        background-position: -11px -9px;
      }
      &.contact-twitter::before {
        background-position: -55px -9px;
      }
    }
  }

  .footer-menus {
    margin: 0;
    padding: 10px 0 0 0;
    list-style-type: none;

    li {
      margin: 0 0 5px 25px;

      &::before {
        display: block;
        position: absolute;
        content: '';
        left: -20px;
        top: 0.2em;
        width: 16px;
        height: 16px;
        background-image: url(../img/list-item.png);
        background-repeat: no-repeat;
        background-position: center;
        background-color: $footer-link-bg;
      }
    }
  }
}
