
@import "_variables";


table {
  thead {
    th,
    td {
      background-color: $primary-dark-1;
      color: $page-bg;
    }
  }
  th,
  td {
    padding-left: 0.5em;
    padding-right: 0.5em;
  }
}
