"use strict";(self.webpackChunkpyams_app_msc=self.webpackChunkpyams_app_msc||[]).push([[305],{3305:(t,e,n)=>{n.r(e),n.d(e,{default:()=>u});var a=n(7363),i=n(2263),r=n(3041),o=n(8680),c=n(9435),l=n(4692),d=function(t,e,n,d){return new Promise((function(u,v){t.data();var f={plugins:[o.Ay,i.A,r.A,c.A],initialView:window.innerWidth<768?"listMonth":"dayGridMonth",themeSystem:"bootstrap",locale:l("html").attr("lang"),headerToolbar:{start:"title",center:"today",right:"prev,next"},bootstrapFontAwesome:{prev:"fa-chevron-left",next:"fa-chevron-right"},firstDay:1,weekNumberCalculation:"ISO",eventDidMount:s.mountedEvent,eventClick:s.clickEvent};f=l.extend({},f,e,n),t.trigger("calendar.init",[t,f]);var h=new a.Vv(t.get(0),f);t.trigger("calendar.finishing",[t,h,f]),d&&d(h,e),t.trigger("calendar.finished",[t,h,f]),h.render(),u(h)}))},s={init:function(t,e,n){var a=l.map(t,(function(t){return new Promise((function(a,i){var r=l(t),o=r.data(),c=o.calendarConfig;c?a(d(r,c,e,n)):l.get(o.calendarUrl||"get-calendar-configuration.json",(function(t){a(d(r,t,e,n))}))}))}));l.when.apply(l,a).then()},mountedEvent:function(t){var e=l(t.el),n=l("html").attr("lang"),a=new Intl.DateTimeFormat(n,{hour:"2-digit",minute:"2-digit"}).format(t.event.start);e.tooltip({title:"".concat(a," - ").concat(t.event.title)})},clickEvent:function(t){var e,n=null===(e=t.event.extendedProps)||void 0===e?void 0:e.href;n&&(window.location.href=n)}};const u=s}}]);