
// Modules imports

import "popper.js";
import "bootstrap";
import "moment";

import "superfish";

import "./app";


// CSS imports

import "../../../../../../pkg/css/dev/msc.css";


/* Version: $version$ */
