

@import "variables";


.list-separated {
  li {
    &:empty {
      display: none;
    }
    &:not(:last-child) {
      &::after {
        display: inline;
        content: attr(data-separator);
        padding-left: 0.5em;
        padding-right: 0.5em;
      }
    }
  }
}