

.carousel {
  .carousel-caption {
      border-radius: 0.5em;
      background-color: rgba(0, 0, 0, 0.5);
  }
  &.carousel-home {
    .carousel-caption {
      top: calc(50% - 3em);
      bottom: inherit;
      font-size: 1.5rem;
      font-weight: $carousel-font-weight;
      line-height: 1.2;
      padding: 0.5em 1em 0;
    }
  }
}
