
const fr = {

    BTN_CLOSE: "Fermer",

    SUCCESS: "Opération effectuée",

    ERROR_OCCURRED: "Une erreur s'est produite !",
    ERRORS_OCCURRED: "Des erreurs se sont produites !"

}

export default fr;
